@@ -183,7 +183,8 @@
 #'   to do calculations and inferences for estimated marginal means, and contain
 #'   nothing that depends on the model-fitting procedure.
 #'   
-#' @seealso Reference grids are of class \code{\link{emmGrid-class}} and several
+#' @seealso Reference grids are of class \code{\link[=emmGrid-class]{emmGrid}},
+#'   and several
 #'   methods exist for them -- for example \code{\link{summary.emmGrid}}. Reference
 #'   grids are fundamental to \code{\link{emmeans}}. Supported models are
 #'   detailed in \href{../doc/models.html}{\code{vignette("models", "emmeans")}}.
@@ -350,6 +351,9 @@ ref_grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
         ref.levels[[xnm]] = NULL
     }
     
+    if (!is.null(attr(data, "pass.it.on")))   # a hook needed by emm_basis.gamlss
+        attr(object, "data") = data
+    
     basis = .chk_emm_basis(object, trms, xlev, grid, ...)
     
     misc = basis$misc
